Method: RADMesh::STL#rotate_x!

Defined in:
lib/radmesh/stl.rb

#rotate_x!(angle) ⇒ STL

Note:

There is also the same method without ! working as expected. It is not in this reference guide, because it is automatically generated.

Rotate the entire mesh about the X axis by the given number of degrees.

The rotation is counter-clockwise about the axis as seen by looking along the positive axis towards the origin.

Parameters:

  • angle (Float)

    angle in degrees

Returns:

  • (STL)

    returns itself



428
429
430
431
# File 'lib/radmesh/stl.rb', line 428

def rotate_x!(angle)
  CADMesh.stl_rotate_x(@stl_ptr, angle)
  self
end