Method: RADMesh::STL#fill_holes!
- Defined in:
- lib/radmesh/stl.rb
#fill_holes! ⇒ STL
Note:
There is also the same method without ! working as expected. It is not in this reference guide, because it is automatically generated.
Fill holes in the mesh by adding facets.
This should be called after #check_facets_exact! and #check_facets_nearby!. If there are still unconnected facets, then facets will be added to the mesh, connecting the unconnected facets, until all of the holes have been filled. This is guaranteed to completely fix all unconnected facets. However, the resulting mesh may or may not be what the user expects.
256 257 258 259 |
# File 'lib/radmesh/stl.rb', line 256 def fill_holes! CADMesh.stl_fill_holes(@stl_ptr) self end |