Method: RADMesh::STL#mirror_yz!
- Defined in:
- lib/radmesh/stl.rb
#mirror_yz! ⇒ STL
Note:
There is also the same method without ! working as expected. It is not in this reference guide, because it is automatically generated.
Mirror the mesh about the YZ plane.
Mirroring involves reversing the sign of all of the coordinates in a particular axis. For example, to mirror a mesh about the XY plane, the signs of all of the Z coordinates in the mesh are reversed.
493 494 495 496 |
# File 'lib/radmesh/stl.rb', line 493 def mirror_yz! CADMesh.stl_mirror_yz(@stl_ptr) self end |